@@ -25,7 +25,7 @@
 char progress[] = "-\\|/";
 #define PROGRESSLEN 4
 #define PROGRESSOFTEN 2500
-#define ONE 0x00000001L
+#define ONE 0x00000001UL
 
 union {
     unsigned char bytes[UL_LEN/8];
@@ -51,12 +51,11 @@ int compare_regions(ulv *bufa, ulv *bufb, size_t count) {
             if (use_phys) {
                 physaddr = physaddrbase + (i * sizeof(ul));
                 fprintf(stderr, 
-                        "FAILURE: 0x%08lx != 0x%08lx at physical address "
-                        "0x%08lx.\n", 
+                        "FAILURE: " FMT_TARGET " != " FMT_TARGET " at physical address " FMT_TARGET ".\n",
                         (ul) *p1, (ul) *p2, physaddr);
             } else {
                 fprintf(stderr, 
-                        "FAILURE: 0x%08lx != 0x%08lx at offset 0x%08lx.\n", 
+                        "FAILURE: " FMT_TARGET " != " FMT_TARGET " at offset " FMT_TARGET ".\n",
                         (ul) *p1, (ul) *p2, (ul) (i * sizeof(ul)));
             }
             /* printf("Skipping to next test..."); */
@@ -92,13 +91,11 @@ int test_stuck_address(ulv *bufa, size_t count) {
                 if (use_phys) {
                     physaddr = physaddrbase + (i * sizeof(ul));
                     fprintf(stderr, 
-                            "FAILURE: possible bad address line at physical "
-                            "address 0x%08lx.\n", 
+                            "FAILURE: possible bad address line at physical address " FMT_TARGET ".\n",
                             physaddr);
                 } else {
                     fprintf(stderr, 
-                            "FAILURE: possible bad address line at offset "
-                            "0x%08lx.\n", 
+                            "FAILURE: possible bad address line at offset " FMT_TARGET ".\n",
                             (ul) (i * sizeof(ul)));
                 }
                 printf("Skipping to next test...\n");
